@@ -8,32 +8,30 @@
 
 """Tests for user profile validators."""
 
-from __future__ import absolute_import, print_function
-
 import pytest
 
 from invenio_userprofiles.validators import validate_username
 
 test_usernames = {
-    'valid': 'Good-Name_9',
-    'invalid_begins_with_number': '9CantStartWithNumber',
-    'invalid_characters': '_Containsi!!ega!Char acters*',
-    'invalid_short': 'ab',
+    "valid": "Good-Name_9",
+    "invalid_begins_with_number": "9CantStartWithNumber",
+    "invalid_characters": "_Containsi!!ega!Char acters*",
+    "invalid_short": "ab",
 }
 
 
 def test_validate_username(app):
     """Test username validator."""
     # Goodname can contain letters, numbers and starts with a letter
-    validate_username(test_usernames['valid'])
+    validate_username(test_usernames["valid"])
 
     # Can't start with a number
     with pytest.raises(ValueError):
-        validate_username(test_usernames['invalid_begins_with_number'])
+        validate_username(test_usernames["invalid_begins_with_number"])
 
     # Can only contain latin letters and numbers
     with pytest.raises(ValueError):
-        validate_username(test_usernames['invalid_characters'])
+        validate_username(test_usernames["invalid_characters"])
 
     with pytest.raises(ValueError):
-        validate_username(test_usernames['invalid_short'])
+        validate_username(test_usernames["invalid_short"])
